@@ -1,6 +1,6 @@
-// Copyright (c) 1998-1999 Peter Karlsson
+// Copyright (c) 1998-2001 Peter Karlsson
 //
-// $Id: version.h,v 1.1 1999/07/16 00:11:05 peter Exp $
+// $Id: version.h,v 1.11.2.1 2001/12/27 19:13:02 peter Exp $
 //
 // This program is free software; you can redistribute it and/or modify
 // it under the terms of the GNU General Public License as published by
@@ -20,6 +20,17 @@
 
 #include <string>
 
-const string version = "1.2";
+#if !defined(HAVE_IMPLICIT_NAMESPACE)
+using namespace std;
+#endif
+
+/** String describing the current version number. */
+const string version = "2.2.1";
+
+/** String describing the copyright information. */
+const string copyright = "(c) Copyright 1998-2001 Peter Karlsson";
+
+/** String describing the release year for this version. */
+const string releaseyear = "2001";
 
 #endif
